KvKey

Enum KvKey 

pub enum KvKey {
    Put {
        namespace: Namespace,
        key: String,
        value: String,
        expiration_ttl: Option<u64>,
        expiration: Option<u64>,
        metadata: Option<String>,
        path: bool,
    },
    Get {
        namespace: Namespace,
        key: String,
    },
    Delete {
        namespace: Namespace,
        key: String,
        force: bool,
    },
    List {
        namespace: Namespace,
        prefix: Option<String>,
    },
}

Variants



Put

Put a key-value pair into a namespace

Fields

namespace: Namespace
key: String

Key to write the value to

value: String

Value for key

expiration_ttl: Option<u64>

Number of seconds for which the entries should be visible before they expire. At least 60. Takes precedence over ‘expiration’ option.

expiration: Option<u64>

Number of seconds since the UNIX epoch, indicating when the key-value pair should expire.

metadata: Option<String>

Arbitrary JSON to associate with a key-value pair. Must be no more than 1024 bytes.

path: bool

The value passed in is a path to a file; open and upload its contents



Get

Get a key’s value from a namespace

Fields

namespace: Namespace
key: String

Key whose value to get



Delete

Delete a key and its value from a namespace

Fields

namespace: Namespace
key: String

Key whose value to get

force: bool

Forces delete without user confirmation



List

List all keys in a namespace. Produces JSON output

Fields

namespace: Namespace
prefix: Option<String>

The prefix for filtering listed keys