pub enum KvKey {
Put {
namespace: Namespace,
key: String,
value: String,
expiration_ttl: Option<u64>,
expiration: Option<u64>,
metadata: Option<String>,
path: bool,
},
Get {
namespace: Namespace,
key: String,
},
Delete {
namespace: Namespace,
key: String,
force: bool,
},
List {
namespace: Namespace,
prefix: Option<String>,
},
}Variants
Put
Put a key-value pair into a namespace
Fields

expiration_ttl: Option<u64>Number of seconds for which the entries should be visible before they expire. At least 60. Takes precedence over ‘expiration’ option.

expiration: Option<u64>Number of seconds since the UNIX epoch, indicating when the key-value pair should expire.
Get
Get a key’s value from a namespace
Delete
Delete a key and its value from a namespace
Fields
List
List all keys in a namespace. Produces JSON output